unit euroform;

{
********************************************************************
* Conventies voor namen van componenten:                           *
*  Bevel      : Bevel1, Bevel2,...                                 *
*  Button     : BtnXxx             Ex.: BtnConvert                 *
*  Edit       : EdXxx              Ex.: EdInput                    *
*  Form       : FormXxx            Ex.: FormMain                   *
*  Label      : LblXxx             Ex.: LblEuro                    *
*  RadioGroup : RGXxxx             Ex.: RGValuta                   *
*  MenuItem   : MenuType1, MenuType2,... voor eerste niveau        *
*                                  Ex.: MenuBestand, MenuHelp      *
*               TypeActie1, TypeActie2,... voor tweede niveau      *
*                                  Ex.: Bestand2Decim, BestandExit *
********************************************************************
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ExtCtrls, Menus;

type
  TFormMain = class(TForm)
    LblEuro: TLabel;
    LblATS: TLabel;
    LblBEF: TLabel;
    LblDEM: TLabel;
    LblESP: TLabel;
    LblFIM: TLabel;
    LblFRF: TLabel;
    LblIEP: TLabel;
    LblITL: TLabel;
    LblNLG: TLabel;
    LblPTE: TLabel;
    EdInput: TEdit;
    BtnConvert: TButton;
    RGValuta: TRadioGroup;
    Bevel1: TBevel;
    RGDecim: TRadioGroup;
    MainMenu1: TMainMenu;
    MenuBestand: TMenuItem;
    BestandExit: TMenuItem;
    Bestand2Decim: TMenuItem;
    Bestand4Decim: TMenuItem;
    FileSeparator: TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure BtnConvertClick(Sender: TObject);
    procedure RGValutaClick(Sender: TObject);
    procedure RGDecimClick(Sender: TObject);
    procedure Bestand2DecimClick(Sender: TObject);
    procedure Bestand4DecimClick(Sender: TObject);
    procedure BestandExitClick(Sender: TObject);
    procedure EdInputKeyPress(Sender: TObject; var Key: Char);
  private
    { Private declarations }
    procedure ValutaConvert;
    procedure ConvertShow;
    procedure SetLabelInvisible;
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

implementation

{$R *.DFM}

const
  // Conversie-factoren voor diverse valuta
  // 1 EURO = X munteenheden
  cfATS  = 13.7603;
  cfBEF  = 40.3399;
  cfDEM  = 1.95583;
  cfESP  = 166.386;
  cfFIM  = 5.94573;
  cfFRF  = 6.55957;
  cfIEP  = 0.787564;
  cfITL  = 1936.27;
  cfNLG  = 2.20371;
  cfPTE  = 200.482;

var
  Euro: Real; // globale variabele voor bedrag in Euro

procedure TFormMain.BtnConvertClick(Sender: TObject);
begin
  ValutaConvert;
end;

procedure TFormMain.RGValutaClick(Sender: TObject);
begin
  ValutaConvert;
end;

procedure TFormMain.RGDecimClick(Sender: TObject);
begin
  { Zet checkmark van menu-item Bestand2Decim aan/uit
    afhankelijk van radiobutton voor 2 decimalen al dan niet
    geselecteerd }
  Bestand2Decim.Checked := (RGDecim.ItemIndex = 0);
  // Zet de tweede checkmark in de tegenovergestelde zin
  Bestand4Decim.Checked := not Bestand2Decim.Checked;
  
  ValutaConvert;
end;

// Bij de start van het programma: de eerste "automatische" conversie
procedure TFormMain.FormCreate(Sender: TObject);
begin
  ValutaConvert;
end;

{ Converteer de inhoud van de EDIT naar EURO,
  converteer naar andere valuta,
  toon resultaten in LABELs.                 }
procedure TFormMain.ValutaConvert;
var
  StartBedrag,    // te converteren bedrag
  CFactor: real;  // conversie-factor
begin
  try
    // Converteer de tekst van de EDIT naar een NUMERIEKE waarde
    StartBedrag := StrToFloat(EdInput.Text);
    { De conversie-factor hangt af van welke radioknop
      geselecteerd is in RADIOGROUP RGValuta           }
    case RGValuta.ItemIndex of
      1 : CFactor := cfATS;
      2 : CFactor := cfBEF;
      3 : CFactor := cfDEM;
      4 : CFactor := cfESP;
      5 : CFactor := cfFIM;
      6 : CFactor := cfFRF;
      7 : CFactor := cfIEP;
      8 : CFactor := cfITL;
      9 : CFactor := cfNLG;
      10: CFactor := cfPTE;
    else
      CFactor := 1; // eerste RadioButton is Euro
    end;
    Euro := StartBedrag / CFactor;   // gewone rekenkunde...
    // Converteer naar andere valuta en toon resultaten
    ConvertShow;
    // Verberg de LABEL die overeenstemt met de geselecteerde RADIOBUTTON
    SetLabelInvisible;
  except
    { Bij een conversie-fout komen we hier terecht,
      ONMIDDELLIJK na de poging om functie StrToFloat()
      uit te voeren                                     }
    on EConvertError do
      MessageDlg('Ongeldige invoer!', mtWarning, [mbOk], 0);
  end;
end;

{ Vermenigvuldig de waarde in Euro met de conversie-factoren,
  converteer naar STRING-formaat en
  toon de resultaten in overeenkomstige LABELS               }
procedure TFormMain.ConvertShow;
var
  FStr: string; // formaat-string
begin
  { Aantal decimalen hangt af van welke knop
    geselecteerd is in RADIOGROUP RGDecim  }
  if RGDecim.ItemIndex = 0 then
    FStr := '0.00'
  else
    FStr := '0.0000';

  { Converteer van Euro naar andere valuta,
    formatteer, voeg valutanamen toe,
    voeg spaties toe om gelijke lengtes te bekomen,
    zet resulterende strings in de CAPTIONs van LABELs }
  LblEuro.Caption := FormatFloat(FStr, Euro)        + ' EURO   ';
  LblATS.Caption := FormatFloat(FStr, Euro * cfATS) + ' ATS    ';
  LblBEF.Caption := FormatFloat(FStr, Euro * cfBEF) + ' BEF/LUF';
  LblDEM.Caption := FormatFloat(FStr, Euro * cfDEM) + ' DEM    ';
  LblESP.Caption := FormatFloat(FStr, Euro * cfESP) + ' ESP    ';
  LblFIM.Caption := FormatFloat(FStr, Euro * cfFIM) + ' FIM    ';
  LblFRF.Caption := FormatFloat(FStr, Euro * cfFRF) + ' FRF    ';
  LblIEP.Caption := FormatFloat(FStr, Euro * cfIEP) + ' IEP    ';
  LblITL.Caption := FormatFloat(FStr, Euro * cfITL) + ' ITL    ';
  LblNLG.Caption := FormatFloat(FStr, Euro * cfNLG) + ' NLG    ';
  LblPTE.Caption := FormatFloat(FStr, Euro * cfPTE) + ' PTE    ';
end;

{ Verberg het LABEL naast de geselecteerde RADIOBUTTON,
  maak de andere LABELs zichtbaar                      }
procedure TFormMain.SetLabelInvisible;
begin
  LblEuro.Visible := (RGValuta.ItemIndex <> 0);
  LblATS.Visible  := (RGValuta.ItemIndex <> 1);
  LblBEF.Visible  := (RGValuta.ItemIndex <> 2);
  LblDEM.Visible  := (RGValuta.ItemIndex <> 3);
  LblESP.Visible  := (RGValuta.ItemIndex <> 4);
  LblFIM.Visible  := (RGValuta.ItemIndex <> 5);
  LblFRF.Visible  := (RGValuta.ItemIndex <> 6);
  LblIEP.Visible  := (RGValuta.ItemIndex <> 7);
  LblITL.Visible  := (RGValuta.ItemIndex <> 8);
  LblNLG.Visible  := (RGValuta.ItemIndex <> 9);
  LblPTE.Visible  := (RGValuta.ItemIndex <> 10);
end;

{ Update check marks in het menu,
  selecteer de eerste RADIOBUTTON van RGDecim
  en voer de conversie-routine uit            }
procedure TFormMain.Bestand2DecimClick(Sender: TObject);
begin
  Bestand2Decim.Checked := True;
  Bestand4Decim.Checked := False;
  RGDecim.ItemIndex := 0;
  ValutaConvert;
end;

{ Update check marks in het menu,
  selecteer de tweede RADIOBUTTON van RGDecim
  en voer de conversie-routine uit            }
procedure TFormMain.Bestand4DecimClick(Sender: TObject);
begin
  Bestand4Decim.Checked := True;
  Bestand2Decim.Checked := False;
  RGDecim.ItemIndex := 1;
  ValutaConvert;
end;

// Sluit de applicatie
procedure TFormMain.BestandExitClick(Sender: TObject);
begin
  { Sluiten van de MAIN form van een applicatie zal
    automatisch de applicatie afsluiten            }
  Close;
end;

{ Indien EdInput de focus heeft en er wordt een op toets gedrukt:
  indien het ENTER was, dan wordt de conversie uitgevoerd;
  indien het KOMMA was en Windows is ingesteld voor het numerieke
  formaat "decimale punt", dan wordt de komma vervangen door
  een PUNT;
  indien het PUNT was en het decimale symbool van Windows is
  ingesteld als KOMMA, dan wordt PUNT vervangen door COMMA.       }

procedure TFormMain.EdInputKeyPress(Sender: TObject; var Key: Char);
begin
  if Key = #13 then  // de code voor ENTER is 13
    ValutaConvert
  else
    { DecimalSeparator is een GLOBAL variabele van Delphi
      die afhangt van Windows' "Regionale Instellingen"  }

    if (Key = ',') and (DecimalSeparator = '.') then
      Key := '.'
    else
      if (Key = '.') and (DecimalSeparator = ',') then
        Key := ',';
end;

end.
